<?php 

/**
 * @file Debugger.class.php
 * @desc Cette classe permet d'effectuer du debug dans un fichier de log notamment avec AMFPHP.
 * 
 * @author Matthieu DELOISON
 * @date Cration 16 Octobre 2006
 * @update
 *
 *
 * @version 0.1 
 */
 
/**
 * @note : 
 *		-  l'avenir, cette classe voluera au fur et  mesure des besoins de debug.
 *		-  tudier, par dfaut les fichier cres par cette classe aura tous une fin de fichier nommm _debug.txt
 */
 
 /**
 * @details : 
 *		- sans prcision d'une url pour la cration du fichier, celui ci se cre dans le mme rpertoire que le fichier php qui instancie la classe Debugger.
 *
 *
 * @usage :
 *		- Debugger::GetInstance()->init("fichier_log.txt", NULL, false); ou Debugger::GetInstance()->init("fichier_log.txt"); // initialisation de la classe
 * 		- Debugger::GetInstance()->addlog("message de test"); // ajouter un message dans le fichier
 *		- Debugger::GetInstance()->clearlog(); // efface le contenu du fichier
 *		- Debugger::GetInstance()->output(); // afficher le contenu du fichier dans la fentre courante
 *
 */
class Debugger 
{
	
	/* constantes */
	private static $o_instance = NULL; // instance unique de rfrence  la classe
	
	
	/* configuration du fichier de sortie */
	private $s_fileLocation; // url complte du fichier de log
	private $b_newFile; // boolen cration d'un nouveau fichier de log ou si = false continuer l'criture de l'ancien fichier.
	private $s_newLog = "\n--------------------------------- NOUVEAU LOG ---------------------------------\n"; //  chaque initialisation du fichier, cration d'une ligne de sparation
	
	
	// ---------------------------------- __construct() ----------------------------------------------------------
   /**
	* @brief Constructeur de la classe. vide pour l'instant.
	* @param -
	*/
	private function __construct()
	{
	
		self::$o_instance = $this;		// Sert pour la mthode static GetInstance()
		
	}

	// -----------------------------------------------------------------------------------------------------------
	// -------------------------------------- Mthodes publiques  ------------------------------------------------
	// -----------------------------------------------------------------------------------------------------------
	
	
	// ---------------------------------- init() ----------------------------------------------------------
 	/**
	* @brief S'occupe de l'initialisation de la classe.
	* @param (string) le nom du fichier de log.
	* @param (string) l'url du fichier de log (optionnel).
	* @param (boolen) cration d'un nouveau fichier true->oui, efface le fichier de mme nom si prsent (optionnel).
	*/
	public function init($s_fileName, $s_fileUrl="", $b_newF=true)
	{
		$this->s_fileLocation = $s_fileUrl.$s_fileName;
		$this->b_newFile = $b_newF;
		
		$this->addlog($this->s_newLog);
	}

	
	// ---------------------------------- addlog() ----------------------------------------------------------
 	/**
	* @brief Ajoute un message dans le fichier de log.
	* @param (string) le essage  ajouter.
	* @return - 
	*/
	public function addlog($s_message)
	{
		// si on doit crer un nouveau ficheir
		if( $this->b_newFile ) $s_param = "w+";// place le pointeur de fichier au dbut du fichier et rduit la taille du fichier  0. Si le fichier n'existe pas, on tente de le crer.
		else  $s_param = "a+b";// ouvre le fichier, le curseur se place  la fin pour continuer l'criture, cration si il n'existe pas, criture des donnes en mode binaire
		
		$handle = fopen($this->s_fileLocation, $s_param); 
		$i_nb_octet = fwrite($handle, $s_message."\n"); // criture dans le fichier
		
		if( $i_nb_octet===FALSE )
		{
			echo "impossible d'crire dans le fichier.";
			exit;
		}

		// sinon criture russi, on ferme le fichier
		fclose($handle);
		return;
	
	}


	// ---------------------------------- clearlog() ----------------------------------------------------------
 	/**
	* @brief Efface le contenu du fichier de log.
	* @param -
	* @return - 
	*/
	public function clearlog()
	{
		$s_message = "--------------- New Log--------------------";
		$handle = fopen($this->s_fileLocation, "w+"); 
		$i_nb_octet = fwrite($handle, $s_message."\n"); // criture dans le fichier
		
		if( $i_nb_octet===FALSE )
		{
			echo "impossible d'crire dans le fichier.";
			exit;
		}
		
		// sinon criture russi, on ferme le fichier
		fclose($handle);
		return;
	}
	


	// ---------------------------------- output() ----------------------------------------------------------
 	/**
	* @brief Effectue un echo de tous le contenu du fichier de log
	* @param - 
	* @return - 
	*/
	public function output()
	{
		if( file_exists($this->s_fileLocation) )
		{ 
			$file = fopen($this->s_fileLocation,'r');
			?>
			<input type="hidden" id="purge" name="purge" value="purge" />
			<textarea name="infos" id="infos" rows="15" cols="150" class="menu"><?php while (!feof($file)){$donnees = fgets($file,255);echo $donnees ;} ?>
			</textarea>
			<?php 
		} 
	}
	
		
	
	// -----------------------------------------------------------------------------------------------------------
	// ---------------------------------------- Mthodes prives  ------------------------------------------------
	// -----------------------------------------------------------------------------------------------------------

	
	

	// -----------------------------------------------------------------------------------------------------------
	// ---------------------------------------- Getter / Setter  -------------------------------------------------
	// -----------------------------------------------------------------------------------------------------------



	// ---------------------------------- GetInstance() ----------------------------------------------------------
	/**
	* @return (Debugger) Renvoie l'instance (unique) de Debugger s'il y en a une, sinon renvoie null. 
	*/
	public static function GetInstance() 
	{
		if ( self::$o_instance == NULL ) self::$o_instance = new Debugger();
		
		return self::$o_instance;
	}


	
 	// -------------------------------------------------------------------------------------------------
	// ---------------------------------------- Divers  ------------------------------------------------
	// -------------------------------------------------------------------------------------------------

	
 	/**
	* @brief Destructeur de la classe
	* Utilis pour enregistrer des messages pour le debogage, fermer les fichier ouverts en criture ou en lecture, raliser des oprations
	* de nettoyage des objets utiliss...
	*
	* @param 
	* @return 
	*/
	public function __destruct() 
	{
 
 	}



	/**
	 * @brief Dtermine comment la classe doit ragir lorsqu'elle est convertie en chane de caractres.
	 * @usage   echo(myObject) ou print(myObject)
	 * @return  la reprsentation de l'objet sous forme de chane.
	 */	
	public function __toString() 
	{
		
		$s_classContent = "[Object ".__CLASS__."]<br />";
		// parcours toutes les proprits de la classe et les renvoie	
		foreach($this as $prop => $value) 
		{
		 	$s_classContent .= "$prop => $value <br />";
		}
		 
		return $s_classContent;
   	}

}
 
 
 

?>